package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: May 22, 2023
License: LGPL-2.1
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
LoadModule is a wrapper for python.LoadModule
type HumanName struct {
Text string `json:"text"`
Detail struct {
Title string `json:"title"`
First string `json:"first"`
Middle string `json:"middle"`
Last string `json:"last"`
Suffix string `json:"suffix"`
Nickname string `json:"nickname"`
} `json:"detail"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.